phoneapp/phoneuiutils/inc/tphonecmdparamtranseffect.h
branchRCL_3
changeset 25 91c2fb4b78df
parent 0 5f000ab63145
child 58 40a3f856b14d
--- a/phoneapp/phoneuiutils/inc/tphonecmdparamtranseffect.h	Wed Apr 14 15:56:42 2010 +0300
+++ b/phoneapp/phoneuiutils/inc/tphonecmdparamtranseffect.h	Tue Apr 27 16:37:10 2010 +0300
@@ -37,21 +37,27 @@
 enum TPhoneTransEffectType
     {
     EPhoneTransEffectNone,
+    // These 3 effect types can be used only when dialer is
+    // opened/closed when some other app than phone is visible 
+    // on the foreground/in the background.
+    // These cannot be used for internal transitions (=call ui<->dialer).
     EPhoneTransEffectDialerOpen,
     EPhoneTransEffectDialerClose,
     EPhoneTransEffectDialerCreate,
+    // For applying effect to external app launch done from dialer.
+    // Effects triggered by App FW don't work properly.
+    EPhoneTransEffectAppStartFromDialer,
     EPhoneTransEffectStop
     };
 
 // CLASS DECLARATION
 
 /**
 *  A parameter class for note dialog information.
 */
 class TPhoneCmdParamTransEffect : public TPhoneUICommandParam
     {   
-   
-    
+
     public: 
            
         /**
@@ -67,19 +73,37 @@
         */
         IMPORT_C void SetType( TPhoneTransEffectType aType );
 
- 
+        /**
+        * Sets application uid associated with the effect.
+        * @param    aAppUid, Id of app.
+        * @return   None.
+        */
+        IMPORT_C void SetAppUid( const TUid& aAppUid );
+
         /**
         * Returns the effect type
         * @return Returns the type
         */
         IMPORT_C TPhoneTransEffectType Type() const;
-   
+
+        /**
+        * Returns App uid associated with the effect.
+        * @param    None.
+        * @return   iAppUid.
+        */
+        IMPORT_C TUid AppUid() const;
+
     private:    
         
         /**
-        * Note type
+        * Effect type
         */
         TPhoneTransEffectType iType;
+        
+        /**
+        * App UID
+        */
+        TUid iAppUid;
 
     };
@@ -37,21 +37,27 @@
 
 /**
-*  A parameter class for note dialog information.
+*  A parameter class for transition effect information.
 */
 class TPhoneCmdParamTransEffect : public TPhoneUICommandParam